@@ -21,12 +21,9 @@
 #include <KWindowSystem>
 
 #include "CommandLineArguments.h"
-#include "Configuration.h"
 #include "ToolsModel.h"
 
-#if KI18N_VERSION >= QT_VERSION_CHECK(6, 8, 0)
 #include <KLocalizedQmlContext>
-#endif
 
 class SessionManager : public QObject
 {
@@ -42,13 +39,8 @@ SessionManager::SessionManager(QObject *parent)
     : QObject(parent)
 {
     connect(qApp, &QGuiApplication::saveStateRequest, this, [this](QSessionManager &manager) {
-        QString lastPageId = Configuration::globalConfig()->lastPage();
-        if (lastPageId.isEmpty()) {
-            return;
-        }
         QStringList args;
         args << qApp->applicationName();
-        args << QStringLiteral("--page-id") << lastPageId;
         args << QStringLiteral("-session") << manager.sessionId();
         manager.setRestartCommand(args);
     });
@@ -70,7 +62,7 @@ int main(int argc, char **argv)
                          /* version */ PROJECT_VERSION,
                          /* shortDescription */ i18n("An application for monitoring system resources"),
                          /* licenseType */ KAboutLicense::GPL,
-                         /* copyrightStatement */ i18n("© 2024 Plasma Development Team"),
+                         /* copyrightStatement */ i18n("© 2025 Plasma Development Team"),
                          /* otherText */ QString{},
                          /* homePageAddress */ QString{}};
     aboutData.setDesktopFileName(QStringLiteral("org.kde.plasma-systemmonitor"));
@@ -104,11 +96,7 @@ int main(int argc, char **argv)
     auto sessionManager = new SessionManager(&app);
 
     QQmlApplicationEngine engine;
-#if KI18N_VERSION < QT_VERSION_CHECK(6, 8, 0)
-    engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
-#else
     engine.rootContext()->setContextObject(new KLocalizedQmlContext(&engine));
-#endif
     engine.loadFromModule("org.kde.systemmonitor", "Main");
 
     QObject::connect(&service, &KDBusService::activateRequested, &engine, []() {
